==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_ml.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ml" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>ഫലങ്ങളൊന്നുമില്ല</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>സംഗീതം</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ചലച്ചിത്രം</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation>സിസ്റ്റം</translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ഉറപ്പാക്കുക</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>ഡെസ്ക്ടോപ്പിൽ നിന്നും നീക്കം ചെയ്യുക</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>ഡോക്കിൽ നിന്നും നീക്കം ചെയ്യുക</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>നീക്കം ചെയ്യുക</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>സംഗീതം</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ചലച്ചിത്രം</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation>സിസ്റ്റം</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>കമ്പ്യൂട്ടർ</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>സംഗീതം</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>ഷട്ട്ഡൗൺ</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>കമ്പ്യൂട്ടർ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>സംഗീതം</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>ഷട്ട്ഡൗൺ</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>കമ്പ്യൂട്ടർ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>സംഗീതം</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>തിരയുക</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ഉറപ്പാക്കുക</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-launcher_5.4.5.orig.tar.xz: dde-launcher-5.4.5/translations/dde-launcher_ml.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ml">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>ഫലങ്ങളൊന്നുമില്ല</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation>സംഗീതം</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ചലച്ചിത്രം</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation>സിസ്റ്റം</translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ഉറപ്പാക്കുക</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>ഡെസ്ക്ടോപ്പിൽ നിന്നും നീക്കം ചെയ്യുക</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>ഡോക്കിൽ നിന്നും നീക്കം ചെയ്യുക</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>നീക്കം ചെയ്യുക</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation>സംഗീതം</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ചലച്ചിത്രം</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation>സിസ്റ്റം</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation type="vanished">കമ്പ്യൂട്ടർ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">സംഗീതം</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="vanished">ഷട്ട്ഡൗൺ</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>കമ്പ്യൂട്ടർ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>സംഗീതം</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>ഷട്ട്ഡൗൺ</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation type="vanished">കമ്പ്യൂട്ടർ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">സംഗീതം</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>തിരയുക</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ഉറപ്പാക്കുക</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
